Exception: SolidQueue::Batch::PendingMigrations
- Inherits:
-
StandardError
- Object
- StandardError
- SolidQueue::Batch::PendingMigrations
- Defined in:
- app/models/solid_queue/batch.rb
Instance Method Summary collapse
-
#initialize(message = "The batches schema hasn't been installed yet. Run `bin/rails solid_queue:update` to copy the pending migrations to your application, and then `bin/rails db:migrate` to run them") ⇒ PendingMigrations
constructor
A new instance of PendingMigrations.
Constructor Details
#initialize(message = "The batches schema hasn't been installed yet. Run `bin/rails solid_queue:update` to copy the pending migrations to your application, and then `bin/rails db:migrate` to run them") ⇒ PendingMigrations
Returns a new instance of PendingMigrations.
8 9 10 |
# File 'app/models/solid_queue/batch.rb', line 8 def initialize( = "The batches schema hasn't been installed yet. Run `bin/rails solid_queue:update` to copy the pending migrations to your application, and then `bin/rails db:migrate` to run them") super end |