Module: SolidQueue::FailedExecution::Batchable
- Extended by:
- ActiveSupport::Concern
- Included in:
- SolidQueue::FailedExecution
- Defined in:
- app/models/solid_queue/failed_execution/batchable.rb
Overview
A FailedExecution is created only after retries are exhausted, when the job stops counting as pending in its batch.